# Supply answers to tests.
$test_1_simple_expected
    = [
          {
            'sheet' => {
                         'Sheet1' => 1,
                         'Sheet3' => 3,
                         'Sheet2' => 2
                       },
            'parsers' => [
                           {
                             'parser' => 'Spreadsheet::ReadGnumeric',
                             'version' => '0.2',
                             'type' => 'gnumeric'
                           }
                         ],
            'type' => 'gnumeric',
            'sheets' => 3,
            'error' => undef,
            'version' => '0.2',
            'parser' => 'Spreadsheet::ReadGnumeric'
          },
          {
            'label' => 'Sheet1',
            'K13' => '=D4',
            'E22' => '1',
            'B36' => '44911',
            'B13' => '44826',
            'F37' => '14.949999999999999',
            'C20' => 'Plumbing',
            'C32' => 'utility',
            'E26' => '1',
            'C18' => 'Credit Card One',
            'B18' => '44844',
            'G9' => '5000',
            'A22' => '503',
            'I3' => 'Reconciled',
            'B35' => '44911',
            'C1' => 'Bank Statement',
            'E12' => '1',
            'B40' => '44921',
            'D33' => '100',
            'H3' => 'Balance',
            'C25' => 'ATM',
            'mincol' => 1,
            'C37' => 'monthly maintenance fee',
            'E15' => '1',
            'C17' => 'ATM',
            'D32' => '149',
            'A3' => 'Number',
            'J21' => 'outst',
            'D38' => '100',
            'J20' => 'bal',
            'G3' => 'Deposit',
            'B17' => '44843',
            'D17' => '100',
            'C30' => 'monthly maintenance fee',
            'D27' => '17.600000000000001',
            'J12' => 'bal',
            'A31' => '507',
            'B42' => '44896',
            'B3' => 'Date',
            'B30' => '44882',
            'E24' => '1',
            'maxrow' => '54',
            'C38' => 'ATM',
            'E14' => '1',
            'C5' => '** 2022 **',
            'J13' => 'outst',
            'C11' => 'check printing charge',
            'K12' => '5235.6000000000004',
            'D23' => '10',
            'B34' => '44907',
            'B14' => '44826',
            'B12' => '44826',
            'D21' => '100',
            'C22' => 'Utility',
            'B22' => '44862',
            'E17' => '1',
            'C39' => 'consulting',
            'C35' => 'Credit Card Two',
            'C21' => 'ATM',
            'A20' => '502',
            'C23' => 'Credit Card Two',
            'B23' => '44862',
            'G15' => '942.89999999999998',
            'K32' => '=D27',
            'J11' => 'Sep',
            'A23' => '504',
            'G24' => '117.59999999999999',
            'D22' => '152',
            'B24' => '44869',
            'A35' => '509',
            'C29' => 'consulting',
            'D14' => '100',
            'B41' => '44896',
            'C16' => 'ATM',
            'A32' => '508',
            'D20' => '925',
            'B31' => '44892',
            'D16' => '100',
            'D19' => '100',
            'D18' => '1238',
            'C31' => 'Comcast (final)',
            'cell' => [
                        [],
                        [
                          undef,
                          undef,
                          undef,
                          'Number',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '501',
                          undef,
                          '502',
                          undef,
                          '503',
                          '504',
                          undef,
                          undef,
                          undef,
                          '505',
                          '506',
                          undef,
                          undef,
                          '507',
                          '508',
                          undef,
                          undef,
                          '509',
                          '510'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Date',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '44816',
                          '44816',
                          '44823',
                          '44826',
                          '44826',
                          '44826',
                          '44838',
                          '44838',
                          '44843',
                          '44844',
                          '44848',
                          '44854',
                          '44860',
                          '44862',
                          '44862',
                          '44869',
                          '44869',
                          '44875',
                          '44877',
                          '44877',
                          '44882',
                          '44882',
                          '44892',
                          '44892',
                          '44895',
                          '44907',
                          '44911',
                          '44911',
                          '44912',
                          '44914',
                          '44921',
                          '44921',
                          '44896',
                          '44896'
                        ],
                        [
                          undef,
                          'Bank Statement',
                          undef,
                          'Description of Transaction',
                          undef,
                          '** 2022 **',
                          undef,
                          'Balance forward',
                          undef,
                          'initial deposit',
                          'consulting',
                          'check printing charge',
                          'consulting',
                          'another charge',
                          'ATM',
                          'consulting',
                          'ATM',
                          'ATM',
                          'Credit Card One',
                          'ATM',
                          'Plumbing',
                          'ATM',
                          'Utility',
                          'Credit Card Two',
                          'consulting',
                          'ATM',
                          'ATM',
                          'National Grid (final)',
                          'Credit Card One',
                          'consulting',
                          'monthly maintenance fee',
                          'Comcast (final)',
                          'utility',
                          'ATM (no receipt)',
                          'ATM',
                          'Credit Card Two',
                          'Credit Card One',
                          'monthly maintenance fee',
                          'ATM',
                          'consulting',
                          'ATM'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Payment',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '36',
                          undef,
                          undef,
                          '100',
                          undef,
                          '100',
                          '100',
                          '1238',
                          '100',
                          '925',
                          '100',
                          '152',
                          '10',
                          undef,
                          '100',
                          '100',
                          '17.600000000000001',
                          '1385',
                          undef,
                          undef,
                          '0.12',
                          '149',
                          '100',
                          '100',
                          '10',
                          '1655',
                          undef,
                          '100',
                          undef,
                          '100'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Code',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          undef,
                          '1',
                          '1',
                          '1'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Fee',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '14.949999999999999',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '14.949999999999999'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Deposit',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '5000',
                          '271.60000000000002',
                          undef,
                          '439.60000000000002',
                          '6.1200000000000001',
                          undef,
                          '942.89999999999998',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '117.59999999999999',
                          undef,
                          undef,
                          undef,
                          undef,
                          '264.60000000000002',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '390.60000000000002'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Balance',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=H7+G9-F9-D9',
                          '=H9+G10-F10-D10'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Reconciled',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=I7+E9*(G9-F9-D9)',
                          '=I9+E10*(G10-F10-D10)'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Sep',
                          'bal',
                          'outst',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Oct',
                          'bal',
                          'outst',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Nov',
                          'bal',
                          'outst'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=K12-K13-H11',
                          '5235.6000000000004',
                          '=D4',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '4986.2200000000003',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '2581.4699999999998',
                          '=D27'
                        ]
                      ],
            'C28' => 'Credit Card One',
            'D34' => '100',
            'D3' => 'Payment',
            'B38' => '44914',
            'C14' => 'ATM',
            'B29' => '44882',
            'C24' => 'consulting',
            'minrow' => 1,
            'H9' => '=H7+G9-F9-D9',
            'C34' => 'ATM',
            'G12' => '439.60000000000002',
            'B27' => '44877',
            'E20' => '1',
            'F3' => 'Fee',
            'C3' => 'Description of Transaction',
            'C10' => 'consulting',
            'A27' => '505',
            'I10' => '=I9+E10*(G10-F10-D10)',
            'B15' => '44838',
            'B10' => '44816',
            'C33' => 'ATM (no receipt)',
            'J31' => 'bal',
            'K31' => '2581.4699999999998',
            'B21' => '44860',
            'I9' => '=I7+E9*(G9-F9-D9)',
            'K11' => '=K12-K13-H11',
            'A28' => '506',
            'E25' => '1',
            'F30' => '14.949999999999999',
            'A18' => '501',
            'D31' => '0.12',
            'C9' => 'initial deposit',
            'C26' => 'ATM',
            'C7' => 'Balance forward',
            'B28' => '44877',
            'B16' => '44838',
            'E21' => '1',
            'D11' => '36',
            'G10' => '271.60000000000002',
            'C36' => 'Credit Card One',
            'J19' => 'Oct',
            'B9' => '44816',
            'D40' => '100',
            'C27' => 'National Grid (final)',
            'K20' => '4986.2200000000003',
            'D26' => '100',
            'E29' => '1',
            'B32' => '44892',
            'C19' => 'ATM',
            'A36' => '510',
            'D36' => '1655',
            'E3' => 'Code',
            'J30' => 'Nov',
            'D28' => '1385',
            'B39' => '44921',
            'E16' => '1',
            'E13' => '1',
            'indx' => 1,
            'E11' => '1',
            'B20' => '44854',
            'G13' => '6.1200000000000001',
            'E9' => '1',
            'H10' => '=H9+G10-F10-D10',
            'C15' => 'consulting',
            'D35' => '10',
            'B19' => '44848',
            'C13' => 'another charge',
            'B26' => '44875',
            'G39' => '390.60000000000002',
            'E19' => '1',
            'E28' => '1',
            'D25' => '100',
            'E30' => '1',
            'C12' => 'consulting',
            'E10' => '1',
            'J32' => 'outst',
            'B25' => '44869',
            'G29' => '264.60000000000002',
            'E18' => '1',
            'B11' => '44823',
            'B33' => '44895',
            'C40' => 'ATM',
            'B37' => '44912',
            'E23' => '1',
            'maxcol' => '256'
          },
          {
            'label' => 'Sheet2',
            'maxcol' => '256',
            'mincol' => 1,
            'indx' => 2
          },
          {
            'label' => 'Sheet3',
            'indx' => 3,
            'mincol' => 1,
            'maxcol' => '256'
          }
        ];

$test_1_simple_no_rc_expected
    = [
          {
            'sheet' => {
                         'Sheet1' => 1,
                         'Sheet3' => 3,
                         'Sheet2' => 2
                       },
            'parsers' => [
                           {
                             'parser' => 'Spreadsheet::ReadGnumeric',
                             'version' => '0.2',
                             'type' => 'gnumeric'
                           }
                         ],
            'parser' => 'Spreadsheet::ReadGnumeric',
            'type' => 'gnumeric',
            'error' => undef,
            'sheets' => 3,
            'version' => '0.2'
          },
          {
            'label' => 'Sheet1',
            'J13' => 'outst',
            'B31' => '44892',
            'A22' => '503',
            'E25' => '1',
            'D34' => '100',
            'C5' => '** 2022 **',
            'D32' => '149',
            'A36' => '510',
            'I10' => '=I9+E10*(G10-F10-D10)',
            'B27' => '44877',
            'E17' => '1',
            'C37' => 'monthly maintenance fee',
            'maxrow' => '54',
            'C36' => 'Credit Card One',
            'G10' => '271.60000000000002',
            'C31' => 'Comcast (final)',
            'C29' => 'consulting',
            'D16' => '100',
            'B13' => '44826',
            'C10' => 'consulting',
            'C32' => 'utility',
            'B14' => '44826',
            'E28' => '1',
            'E11' => '1',
            'B25' => '44869',
            'C16' => 'ATM',
            'K13' => '=D4',
            'B21' => '44860',
            'G15' => '942.89999999999998',
            'C11' => 'check printing charge',
            'B35' => '44911',
            'C21' => 'ATM',
            'C3' => 'Description of Transaction',
            'D18' => '1238',
            'F37' => '14.949999999999999',
            'J32' => 'outst',
            'E19' => '1',
            'B9' => '44816',
            'E21' => '1',
            'A31' => '507',
            'B32' => '44892',
            'C18' => 'Credit Card One',
            'D38' => '100',
            'C1' => 'Bank Statement',
            'J19' => 'Oct',
            'C24' => 'consulting',
            'K12' => '5235.6000000000004',
            'B28' => '44877',
            'E10' => '1',
            'D17' => '100',
            'G9' => '5000',
            'C30' => 'monthly maintenance fee',
            'B40' => '44921',
            'B29' => '44882',
            'A3' => 'Number',
            'D14' => '100',
            'G24' => '117.59999999999999',
            'K20' => '4986.2200000000003',
            'E12' => '1',
            'J30' => 'Nov',
            'G13' => '6.1200000000000001',
            'G39' => '390.60000000000002',
            'B17' => '44843',
            'D20' => '925',
            'E13' => '1',
            'H9' => '=H7+G9-F9-D9',
            'B22' => '44862',
            'C35' => 'Credit Card Two',
            'C34' => 'ATM',
            'F3' => 'Fee',
            'B38' => '44914',
            'indx' => 1,
            'B41' => '44896',
            'C9' => 'initial deposit',
            'C17' => 'ATM',
            'mincol' => 1,
            'G12' => '439.60000000000002',
            'B36' => '44911',
            'B33' => '44895',
            'B20' => '44854',
            'F30' => '14.949999999999999',
            'E16' => '1',
            'E29' => '1',
            'B3' => 'Date',
            'B42' => '44896',
            'E14' => '1',
            'E15' => '1',
            'minrow' => 1,
            'B19' => '44848',
            'H10' => '=H9+G10-F10-D10',
            'B26' => '44875',
            'C19' => 'ATM',
            'A27' => '505',
            'A28' => '506',
            'D3' => 'Payment',
            'K11' => '=K12-K13-H11',
            'C33' => 'ATM (no receipt)',
            'J31' => 'bal',
            'B12' => '44826',
            'D19' => '100',
            'D23' => '10',
            'G29' => '264.60000000000002',
            'C22' => 'Utility',
            'B15' => '44838',
            'B18' => '44844',
            'C27' => 'National Grid (final)',
            'J21' => 'outst',
            'E30' => '1',
            'C20' => 'Plumbing',
            'C39' => 'consulting',
            'D35' => '10',
            'B10' => '44816',
            'H3' => 'Balance',
            'D28' => '1385',
            'B11' => '44823',
            'J12' => 'bal',
            'C15' => 'consulting',
            'D31' => '0.12',
            'D25' => '100',
            'E9' => '1',
            'C40' => 'ATM',
            'J20' => 'bal',
            'B34' => '44907',
            'I3' => 'Reconciled',
            'K32' => '=D27',
            'A23' => '504',
            'B37' => '44912',
            'B23' => '44862',
            'C26' => 'ATM',
            'E22' => '1',
            'B24' => '44869',
            'C12' => 'consulting',
            'C7' => 'Balance forward',
            'E18' => '1',
            'J11' => 'Sep',
            'C28' => 'Credit Card One',
            'I9' => '=I7+E9*(G9-F9-D9)',
            'D33' => '100',
            'G3' => 'Deposit',
            'A18' => '501',
            'B30' => '44882',
            'A32' => '508',
            'E20' => '1',
            'D21' => '100',
            'C13' => 'another charge',
            'C23' => 'Credit Card Two',
            'D22' => '152',
            'C14' => 'ATM',
            'E26' => '1',
            'K31' => '2581.4699999999998',
            'maxcol' => '256',
            'D40' => '100',
            'D36' => '1655',
            'A20' => '502',
            'C25' => 'ATM',
            'E23' => '1',
            'E3' => 'Code',
            'E24' => '1',
            'D27' => '17.600000000000001',
            'D11' => '36',
            'B16' => '44838',
            'A35' => '509',
            'C38' => 'ATM',
            'D26' => '100',
            'B39' => '44921'
          },
          {
            'label' => 'Sheet2',
            'maxcol' => '256',
            'indx' => 2,
            'mincol' => 1
          },
          {
            'label' => 'Sheet3',
            'mincol' => 1,
            'maxcol' => '256',
            'indx' => 3
          }
        ];

$test_1_simple_no_cells_expected
    = [
          {
            'sheet' => {
                         'Sheet1' => 1,
                         'Sheet3' => 3,
                         'Sheet2' => 2
                       },
            'parsers' => [
                           {
                             'parser' => 'Spreadsheet::ReadGnumeric',
                             'version' => '0.2',
                             'type' => 'gnumeric'
                           }
                         ],
            'type' => 'gnumeric',
            'sheets' => 3,
            'version' => '0.2',
            'error' => undef,
            'parser' => 'Spreadsheet::ReadGnumeric'
          },
          {
            'label' => 'Sheet1',
            'cell' => [
                        [],
                        [
                          undef,
                          undef,
                          undef,
                          'Number',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '501',
                          undef,
                          '502',
                          undef,
                          '503',
                          '504',
                          undef,
                          undef,
                          undef,
                          '505',
                          '506',
                          undef,
                          undef,
                          '507',
                          '508',
                          undef,
                          undef,
                          '509',
                          '510'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Date',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '44816',
                          '44816',
                          '44823',
                          '44826',
                          '44826',
                          '44826',
                          '44838',
                          '44838',
                          '44843',
                          '44844',
                          '44848',
                          '44854',
                          '44860',
                          '44862',
                          '44862',
                          '44869',
                          '44869',
                          '44875',
                          '44877',
                          '44877',
                          '44882',
                          '44882',
                          '44892',
                          '44892',
                          '44895',
                          '44907',
                          '44911',
                          '44911',
                          '44912',
                          '44914',
                          '44921',
                          '44921',
                          '44896',
                          '44896'
                        ],
                        [
                          undef,
                          'Bank Statement',
                          undef,
                          'Description of Transaction',
                          undef,
                          '** 2022 **',
                          undef,
                          'Balance forward',
                          undef,
                          'initial deposit',
                          'consulting',
                          'check printing charge',
                          'consulting',
                          'another charge',
                          'ATM',
                          'consulting',
                          'ATM',
                          'ATM',
                          'Credit Card One',
                          'ATM',
                          'Plumbing',
                          'ATM',
                          'Utility',
                          'Credit Card Two',
                          'consulting',
                          'ATM',
                          'ATM',
                          'National Grid (final)',
                          'Credit Card One',
                          'consulting',
                          'monthly maintenance fee',
                          'Comcast (final)',
                          'utility',
                          'ATM (no receipt)',
                          'ATM',
                          'Credit Card Two',
                          'Credit Card One',
                          'monthly maintenance fee',
                          'ATM',
                          'consulting',
                          'ATM'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Payment',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '36',
                          undef,
                          undef,
                          '100',
                          undef,
                          '100',
                          '100',
                          '1238',
                          '100',
                          '925',
                          '100',
                          '152',
                          '10',
                          undef,
                          '100',
                          '100',
                          '17.600000000000001',
                          '1385',
                          undef,
                          undef,
                          '0.12',
                          '149',
                          '100',
                          '100',
                          '10',
                          '1655',
                          undef,
                          '100',
                          undef,
                          '100'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Code',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          '1',
                          undef,
                          '1',
                          '1',
                          '1'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Fee',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '14.949999999999999',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '14.949999999999999'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Deposit',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '5000',
                          '271.60000000000002',
                          undef,
                          '439.60000000000002',
                          '6.1200000000000001',
                          undef,
                          '942.89999999999998',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '117.59999999999999',
                          undef,
                          undef,
                          undef,
                          undef,
                          '264.60000000000002',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '390.60000000000002'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Balance',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=H7+G9-F9-D9',
                          '=H9+G10-F10-D10'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          'Reconciled',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=I7+E9*(G9-F9-D9)',
                          '=I9+E10*(G10-F10-D10)'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Sep',
                          'bal',
                          'outst',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Oct',
                          'bal',
                          'outst',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          'Nov',
                          'bal',
                          'outst'
                        ],
                        [
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '=K12-K13-H11',
                          '5235.6000000000004',
                          '=D4',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '4986.2200000000003',
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          undef,
                          '2581.4699999999998',
                          '=D27'
                        ]
                      ],
            'indx' => 1,
            'maxrow' => '54',
            'mincol' => 1,
            'maxcol' => '256',
            'minrow' => 1
          },
          {
            'label' => 'Sheet2',
            'mincol' => 1,
            'indx' => 2,
            'maxcol' => '256'
          },
          {
            'label' => 'Sheet3',
            'maxcol' => '256',
            'indx' => 3,
            'mincol' => 1
          }
        ];

# Attributes from column C.
$test_1_expected_attrs_5
    = {
	'uline' => '0',
            'format' => 'yyyy\\-mm\\-dd',
            'indent' => '0',
            'bgcolor' => 'FFFF:FFFF:FFFF',
            'valign' => 'bottom',
            'font' => 'Courier New',
            'rotation' => '0',
            'shade' => '0',
            'halign' => 'general',
            'pattern_color' => '0:0:0',
            'bold' => '0',
            'script' => '0',
            'italic' => '0',
            'locked' => '1',
            'hidden' => '0',
            'strike_through' => '0',
            'wrap' => '0',
            'shrink_to_fit' => '0',
            'fgcolor' => '0:0:0',
            'size' => '14'
};
$test_1_expected_attrs_9
    = {
	'hidden' => '0',
            'locked' => '1',
            'wrap' => '0',
            'strike_through' => '0',
            'size' => '14',
            'fgcolor' => '0:0:0',
            'shrink_to_fit' => '0',
            'bgcolor' => 'FFFF:FFFF:FFFF',
            'format' => 'yyyy\\-mm\\-dd',
            'indent' => '0',
            'uline' => '0',
            'rotation' => '0',
            'font' => 'Courier New',
            'valign' => 'bottom',
            'pattern_color' => '0:0:0',
            'bold' => '0',
            'shade' => '0',
            'halign' => 'general',
            'italic' => '0',
            'script' => '0'
};
$test_1_expected_attrs
    = [
          undef,
          {
            'italic' => '0',
            'script' => '0',
            'halign' => 'general',
            'shade' => '0',
            'pattern_color' => '0:0:0',
            'bold' => '0',
            'font' => 'Sans',
            'rotation' => '0',
            'valign' => 'bottom',
            'format' => 'General',
            'indent' => '0',
            'uline' => '0',
            'bgcolor' => 'FFFF:FFFF:FFFF',
            'fgcolor' => '0:0:0',
            'shrink_to_fit' => '0',
            'size' => '14',
            'strike_through' => '0',
            'wrap' => '0',
            'locked' => '1',
            'hidden' => '0'
          },
          undef,
          {
            'shrink_to_fit' => '0',
            'fgcolor' => '0:0:0',
            'size' => '12',
            'locked' => '1',
            'hidden' => '0',
            'strike_through' => '0',
            'wrap' => '0',
            'shade' => '0',
            'halign' => 'general',
            'bold' => '0',
            'pattern_color' => '0:0:0',
            'script' => '0',
            'italic' => '0',
            'uline' => '0',
            'indent' => '0',
            'format' => 'General',
            'bgcolor' => 'FFFF:FFFF:FFFF',
            'valign' => 'bottom',
            'rotation' => '0',
            'font' => 'Sans'
          },
          undef,
	  $test_1_expected_attrs_5,
          undef,
          $test_1_expected_attrs_5,
          undef,
	$test_1_expected_attrs_9,
	$test_1_expected_attrs_9
];

1;
